@@ -1,8 +1,8 @@
 #include <stdio.h>
 
-extern void argless() {
+#include "ffi_test.h"
+
+extern EXPORT void argless() {
 	printf("ok - argless\n");
 	fflush(stdout);
 }
-
-void boot_01_argless() {}
